@@ -16,6 +16,7 @@ test_that("chickpea_estimateV_asreml42", {
                        residual = ~ idv(Smarthouse):ar1(Lane):ar1(Position), 
                        data = chkpeadat, maxit = 13)
 
+  
   #'## estimate with fixed spline - no G terms in V matrix
   Vnospl <- estimateV(asreml.obj, fixed.spline.terms = "Smarthouse:spl(vLanes)")
   
@@ -131,6 +132,31 @@ test_that("chickpea_estimateV_asreml42", {
   Gdsum <- estimateV(asreml.obj, which.matrix = "G")
   Rdsum <- estimateV(asreml.obj, which.matrix = "R")
   testthat::expect_false(any(abs(Gdsum + Rdsum - V) > 1e-08))
+
+  #Spatial correlation in random model and nuggets in residual model 
+  asreml.obj <- asreml(fixed = Biomass.plant ~ Lines * TRT + Smarthouse/(vLanes + vPos), 
+                       random = ~ 
+                         at(Smarthouse, 'SW'):spl(vLanes) + at(Smarthouse, 'SE'):spl(vLanes) +
+                         at(Smarthouse, 'SW'):ar1(Lane):ar1(Position) + 
+                         at(Smarthouse, 'SE'):ar1(Lane):ar1(Position), 
+                       residual =  ~ dsum(~ units | Smarthouse, levels = list(c('SW'))) +
+                         dsum(~ units | Smarthouse, levels = list(c('SE'))), 
+                       data = chkpeadat, maxit = 30)
+  
+  #'## estimate with fixed spline - no G terms in V matrix
+  Vnospl <- estimateV(asreml.obj, 
+                      fixed.spline.terms = c("at(Smarthouse, 'SW'):spl(vLanes)",  
+                                             "at(Smarthouse, 'SE'):spl(vLanes)"))
+  
+  # Form variance matrix based on estimated variance parameters
+  V <- mat.dirsum(list(asreml.obj$vparameters[3] * 
+                         kronecker(mat.ar1(asreml.obj$vparameters[4], length(levels(chkpeadat$Lane))),
+                                   mat.ar1(asreml.obj$vparameters[5], length(levels(chkpeadat$Position)))),
+                       asreml.obj$vparameters[6] * 
+                         kronecker(mat.ar1(asreml.obj$vparameters[7], length(levels(chkpeadat$Lane))),
+                                   mat.ar1(asreml.obj$vparameters[8], length(levels(chkpeadat$Position))))))
+  V <- diag(rep(asreml.obj$vparameters[9:10], each = 528),1056) %*% V
+  testthat::expect_true(any(abs(Vnospl - V) > 1e-08))
 })
 
 
@@ -282,7 +308,7 @@ test_that("Orange_estimateV_str_asreml42", {
   orange <- within(orange, 
                    {
                      x2 <- x^2
-                     cx <- x - mean(unique(2))
+                     cx <- as.numfac(x, center = TRUE)
                      cx2 <- cx^2
                    })
   asreml.options(design = TRUE)
@@ -339,13 +365,13 @@ test_that("Orange_estimateV_str_asreml42", {
   testthat::expect_true(all.equal(G, V.g, tol = 1e-03))
   
   ##Correlated slope and intercept - cor
-  asreml.obj <- asreml(circ ~ x,
-                       random = ~ str( ~Tree/(x + x2), ~cor(3):id(5)),
+  asreml.obj <- asreml(circ ~ cx,
+                       random = ~ str( ~Tree/(cx + cx2), ~cor(3):id(5)),
                        data = orange, maxit=50)   
   (vpar <- asreml.obj$vparameters)
-  g <- matrix(vpar[1], nrow = 3, ncol = 3)
+  g <- matrix(vpar[2], nrow = 3, ncol = 3)
   diag(g) <- 1
-  G.g <- kronecker(matrix(g, nrow = 3), mat.I(5))
+  G.g <- vpar[1] * kronecker(matrix(g, nrow = 3), mat.I(5))
   Z <- as.matrix(asreml.obj$design[,3:17] )
   V.g <- asreml.obj$sigma2 *(Z %*% G.g %*% t(Z))
   G <- estimateV(asreml.obj, which.matrix = "G", bound.exclusions = NULL)
@@ -353,8 +379,8 @@ test_that("Orange_estimateV_str_asreml42", {
   testthat::expect_true(all.equal(G,V.g, tol = 1e-03)) #problem with bound variance 08/2025
   
   ##Correlated slope and intercept - ar1
-  asreml.obj <- asreml(circ ~ x,
-                       random = ~ str( ~Tree/(x + x2), ~ar1(3):id(5)),
+  asreml.obj <- asreml(circ ~ cx,
+                       random = ~ str( ~Tree/(cx + cx2), ~ar1(3):id(5)),
                        data = orange, maxit=20)   
   (vpar <- asreml.obj$vparameters)
   g <- mat.ar1(vpar[2], 3)
